@@ -14,12 +14,14 @@
  * @package    Settings
  *
  */
-
 return array(
 	'groups' => array(
 		'fcgid' => array(
 			'title' => $lng['admin']['fcgid_settings'],
-			'websrv_avail' => array('apache2', 'lighttpd'),
+			'websrv_avail' => array(
+				'apache2',
+				'lighttpd'
+			),
 			'fields' => array(
 				'system_mod_fcgid_enabled' => array(
 					'label' => $lng['serversettings']['mod_fcgid'],
@@ -28,9 +30,12 @@ return array(
 					'type' => 'bool',
 					'default' => false,
 					'save_method' => 'storeSettingField',
-					'plausibility_check_method' => 'checkFcgidPhpFpm',
-					'overview_option' => true
+					'plausibility_check_method' => array(
+						'\\Froxlor\\Validate\\Check',
+						'checkFcgidPhpFpm'
 					),
+					'overview_option' => true
+				),
 				'system_mod_fcgid_configdir' => array(
 					'label' => $lng['serversettings']['mod_fcgid']['configdir'],
 					'settinggroup' => 'system',
@@ -38,9 +43,12 @@ return array(
 					'type' => 'string',
 					'string_type' => 'confdir',
 					'default' => '/var/www/php-fcgi-scripts/',
-					'plausibility_check_method' => 'checkPathConflicts',
-					'save_method' => 'storeSettingField',
+					'plausibility_check_method' => array(
+						'\\Froxlor\\Validate\\Check',
+						'checkPathConflicts'
 					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_mod_fcgid_tmpdir' => array(
 					'label' => $lng['serversettings']['mod_fcgid']['tmpdir'],
 					'settinggroup' => 'system',
@@ -48,8 +56,8 @@ return array(
 					'type' => 'string',
 					'string_type' => 'dir',
 					'default' => '/var/customers/tmp/',
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_mod_fcgid_peardir' => array(
 					'label' => $lng['serversettings']['mod_fcgid']['peardir'],
 					'settinggroup' => 'system',
@@ -59,34 +67,39 @@ return array(
 					'string_delimiter' => ':',
 					'string_emptyallowed' => true,
 					'default' => '/usr/share/php/:/usr/share/php5/',
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_mod_fcgid_wrapper' => array(
 					'label' => $lng['serversettings']['mod_fcgid']['wrapper'],
 					'settinggroup' => 'system',
 					'varname' => 'mod_fcgid_wrapper',
 					'type' => 'option',
-					'option_options' => array(0 => 'ScriptAlias', 1=> 'FcgidWrapper'),
+					'option_options' => array(
+						0 => 'ScriptAlias',
+						1 => 'FcgidWrapper'
+					),
 					'default' => 1,
 					'save_method' => 'storeSettingField',
-					'websrv_avail' => array('apache2')
-					),
+					'websrv_avail' => array(
+						'apache2'
+					)
+				),
 				'system_mod_fcgid_starter' => array(
 					'label' => $lng['serversettings']['mod_fcgid']['starter'],
 					'settinggroup' => 'system',
 					'varname' => 'mod_fcgid_starter',
 					'type' => 'int',
 					'default' => 0,
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_mod_fcgid_maxrequests' => array(
 					'label' => $lng['serversettings']['mod_fcgid']['maxrequests'],
 					'settinggroup' => 'system',
 					'varname' => 'mod_fcgid_maxrequests',
 					'type' => 'int',
 					'default' => 250,
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_mod_fcgid_defaultini' => array(
 					'label' => $lng['serversettings']['mod_fcgid']['defaultini'],
 					'settinggroup' => 'system',
@@ -94,9 +107,11 @@ return array(
 					'type' => 'option',
 					'default' => '1',
 					'option_mode' => 'one',
-					'option_options_method' => 'getPhpConfigs',
-					'save_method' => 'storeSettingField',
-					),
+					'option_options_method' => array(
+						'\\Froxlor\\Http\\PhpConfig',
+						'getPhpConfigs'),
+					'save_method' => 'storeSettingField'
+				),
 				'system_mod_fcgid_idle_timeout' => array(
 					'label' => $lng['serversettings']['mod_fcgid']['idle_timeout'],
 					'settinggroup' => 'system',
@@ -104,10 +119,10 @@ return array(
 					'type' => 'int',
 					'default' => 30,
 					'save_method' => 'storeSettingField'
-					)
 				)
 			)
 		)
-	);
+	)
+);
 
 ?>
