@@ -502,7 +502,7 @@ class AcmeSh extends \Froxlor\Cron\FroxlorCron
 
 		if (is_dir($certificate_folder) && file_exists($ssl_file) && is_readable($ssl_file)) {
 			$cert_data = openssl_x509_parse(file_get_contents($ssl_file));
-			if ($cert_data['validTo_time_t'] > strtotime($cert_date)) {
+			if ($cert_data && $cert_data['validTo_time_t'] > strtotime($cert_date)) {
 				return true;
 			}
 		}
