@@ -4,6 +4,12 @@ namespace Froxlor\Validate;
 class Validate
 {
 
+	const REGEX_DIR = '/^|(\/[\w-]+)+$/';
+
+	const REGEX_PORT = '/^(([1-9])|([1-9][0-9])|([1-9][0-9][0-9])|([1-9][0-9][0-9][0-9])|([1-5][0-9][0-9][0-9][0-9])|(6[0-4][0-9][0-9][0-9])|(65[0-4][0-9][0-9])|(655[0-2][0-9])|(6553[0-5]))$/Di';
+
+	const REGEX_CONF_TEXT = '/^[^\0]*$/';
+
 	/**
 	 * Validates the given string by matching against the pattern, prints an error on failure and exits
 	 *
