@@ -4,6 +4,7 @@ use PHPUnit\Framework\TestCase;
 use Froxlor\Settings;
 use Froxlor\Api\Commands\Customers;
 use Froxlor\Api\Commands\DomainZones;
+use Froxlor\Api\Commands\Domains;
 
 /**
  *
@@ -116,6 +117,10 @@ class DomainZonesTest extends TestCase
 		$result = json_decode($json_result, true)['data'];
 		$this->assertEquals(1, $result['count']);
 		$this->assertEquals('www2', $result['list'][0]['record']);
+
+		$json_result = DomainZones::getLocal($admin_userdata, $data)->listingCount();
+		$result = json_decode($json_result, true)['data'];
+		$this->assertEquals(1, $result);
 	}
 
 	/**
@@ -715,6 +720,31 @@ class DomainZonesTest extends TestCase
 		DomainZones::getLocal($admin_userdata, $data)->add();
 	}
 
+	/**
+	 *
+	 * @depends testAdminDomainZonesAddCname
+	 */
+	public function testAdminDomainZonesAddCnameInvalidWwwAlias()
+	{
+		global $admin_userdata;
+
+		// set domain to www-alias
+		$data = [
+			'domainname' => 'test2.local',
+			'selectserveralias' => '1'
+		];
+		Domains::getLocal($admin_userdata, $data)->update();
+
+		$data = [
+			'domainname' => 'test2.local',
+			'record' => 'www',
+			'type' => 'CNAME',
+			'content' => 'testing.local'
+		];
+		$this->expectExceptionMessage('Cannot set CNAME record for "www" as domain is set to generate a www-alias. Please change settings to either "No alias" or "Wildcard alias"');
+		DomainZones::getLocal($admin_userdata, $data)->add();
+	}
+
 	/**
 	 *
 	 * @depends testAdminDomainZonesAddCname
